# Install This Plugin


To include this plugin as part of your local or institutional NOMAD Oasis the following
line needs to be added to the `pyproject.toml` file of the Oasis repo:
```git+https://github.com/FAIRmat-NFDI/nomad-catalysis-plugin.git@main```

For a detailed guide on how to setup and install a new Oasis, see the [Tutorial 13 part 4](https://github.com/FAIRmat-NFDI/AreaA-Examples/tree/main/tutorial13/part4)


## Add This Plugin to Your NOMAD installation

Read the [NOMAD plugin documentation](https://nomad-lab.eu/prod/v1/staging/docs/plugins/plugins.html#add-a-plugin-to-your-nomad) for all details on how to deploy the plugin on your NOMAD instance.